@@ -1,4 +1,4 @@
-package oo_sub v1.0.0;
+package oo_sub v1.0.1;
 
 use strict;
 use warnings;
@@ -41,21 +41,21 @@ oo_sub - Use object-oriented versions of built-in Perl functions
 
 =head1 SYNOPSIS
 
-use oo_sub;
+  use oo_sub;
 
-say p my $user = getpwnam('root');
+  say p my $user = getpwnam('root');
 
-say p my $group = getgrgid(0);
+  say p my $group = getgrgid(0);
 
-say p my $file = stat('.');
+  say p my $file = stat('.');
 
-say p my $time = localtime('.');
+  say p my $time = localtime('.');
 
-say p my $network = getnetbyname('loopback');
+  say p my $network = getnetbyname('loopback');
 
-say p my $protocol = getprotobyname('tcp');
+  say p my $protocol = getprotobyname('tcp');
 
-say p my $service = getservbyname('ftp');
+  say p my $service = getservbyname('ftp');
 
 =head1 DESCRIPTION
 
@@ -83,12 +83,19 @@ Uses L<autoload_remote|Module::Load/autoload_remote> to achieve this.
 
 =cut
 
+=head1 AUTHOR
+
+Elvin Aslanov <rwp.primary@gmail.com>
+
+=head1 COPYRIGHT
+
+This library is free software; you may redistribute and/or modify it
+under the same terms as Perl itself.
+
 =head1 SEE ALSO
 
 L<User::pwent>, L<File::stat>, L<Time::Piece>, L<Module:Load>
 
-=head1 AUTHOR
 
-Elvin Aslanov
 
 =cut
